The mosaik-docker package
=========================


This package eases the deployment of the `mosaik co-simulation framework`_ with Docker.

.. _mosaik co-simulation framework: https://mosaik.offis.de/

This package provides:
 * an extension to the mosaik framework that allows to start and run simulators as separate Docker containers
 * a command line interface (CLI) that eases the deployment of dockerized mosaik simulations

For details, please refer to the `documentation`_.

.. _documentation: https://mosaik-docker.readthedocs.io/en/latest/index.html
